# Pysharp

### Install
To use Pysharp in a new Unity3D project just drop [pysharp.dll](https://github.com/rmst/pysharp/raw/main/pysharp.dll) somewhere into the project's `Assets` directory.

Install the Python package via
```bash
pip install pysharp
```


### Usage






### License
Pysharp is an alpha release at the moment. Usage of this version is free for everyone. Future versions will remain free for private use but otherwise might or might not become for-pay.